.. -*- coding: utf-8 -*-

.. _geometry:

==========
Polyhedra
==========

Here you can find various documents that explain how to perform polyhedral computations in Sage.

.. toctree::
   :maxdepth: 1

   geometry/polyhedra_quicktutorial
   geometry/polyhedra_tutorial
   geometry/polyhedra_quickref
   geometry/tips
   geometry/visualization
   geometry/polytope_tikz
